@@ -1,51 +1,53 @@
 """ Inferex CLI main command group & core commands. """
 import sys
 import time
-from typing import Optional
 from datetime import datetime, timedelta, timezone
 from pathlib import Path
+from typing import Optional
 
 import click
 import yaml
 
 from inferex import __version__
-from inferex.sdk.resources import deployment, log
-from inferex.sdk.http import login
-from inferex.cli.utils import AliasedGroup, fetch_and_handle_response
-from inferex.utils.io import error, success, default_project, display_logs, TIME_HELP_TEXT, get_commit_sha_and_date
-from inferex.cli.commands.projects import commands as project_commands, projects
-from inferex.cli.commands.deployments import commands as deployment_commands, deployments
-from inferex.cli.commands.pipelines import pipelines
-from inferex.cli.utils import disable_user_prompts
-from inferex.sdk.settings import settings
+from inferex.cli.commands.deployments import commands as deployment_commands
+from inferex.cli.commands.deployments import deployments_list
+from inferex.cli.commands.pipelines import commands as pipeline_commands
+from inferex.cli.commands.pipelines import pipelines_list
+from inferex.cli.commands.projects import commands as project_commands
+from inferex.cli.commands.projects import projects_list
+from inferex.cli.utils import (CustomGroup, disable_user_prompts,
+                               fetch_and_handle_response)
 from inferex.sdk.exceptions import DeployFailureError
-from inferex.utils.io.scanning import RequirementsValidationException
+from inferex.sdk.http import login
+from inferex.sdk.resources import deployments, logs
+from inferex.sdk.settings import settings
+from inferex.cli.display import TIME_HELP_TEXT, display_logs
+from inferex.cli.terminal_format import error, success
+from inferex.common.project import DEFAULT_PROJECT
 
 
-@click.command(cls=AliasedGroup, name="inferex")
-@click.version_option(version=f"{__version__} {get_commit_sha_and_date()}")
+@click.command(cls=CustomGroup, name="inferex")
+@click.version_option(version=__version__)
 def cli():
     """
-    Inferex CLI is a tool that enables AI companies to rapidly deploy pipelines.
-    Init, deploy, and manage your projects with Inferex.
-    Invoke "inferex --help" for a list of commands.
+    Rapidly deploy and manage Inferex pipelines
     """
 
 
 # Core commands
 @cli.command()
 @click.argument("project_path", default=".", type=click.Path(exists=True))
-@click.option("--project-name", prompt="Enter Project name")
+@click.option("--project-name", prompt="Enter Project name", help="Name of project")
 @disable_user_prompts
 def init(project_path: str, project_name: Optional[str], _: Optional[str]):
     """
-    ✨  Initializes a new project. Nondestructive.
+    ✨  Initialize a new project
 
-        project_path: Full or relative path to a project folder.
+        PROJECT_PATH: full or relative path to a project directory.
 
     \f
     Args:
-        path: Full or relative path to project folder.
+        path: Full or relative path to project directory.
     """
     path = Path(project_path)
 
@@ -58,9 +60,9 @@ def init(project_path: str, project_name: Optional[str], _: Optional[str]):
     # Create inferex.yaml
     with open(yaml_file, "w", encoding="utf-8") as file:
         if project_name:
-            yaml.dump({"project": {"name": project_name}, "scaling": {"replicas": 1}}, file)
-        else:
-            yaml.dump(default_project, file)
+            DEFAULT_PROJECT['project']['name'] = project_name
+
+        yaml.dump(DEFAULT_PROJECT, file)
 
     success(f"Project {project_name} initialized in {path.absolute()}")
     click.echo("📝 Edit the 'inferex.yaml' file to customize deployment parameters.")
@@ -69,12 +71,12 @@ def init(project_path: str, project_name: Optional[str], _: Optional[str]):
 @cli.command("login", context_settings=dict(allow_extra_args=True))
 @click.option(
     "--username",
-    help="Your Inferex username.",
+    help="Inferex username.",
     prompt="👤 Inferex Username",
     default=None,
 )
 @click.password_option(
-    help="Your Inferex password.",
+    help="Inferex password.",
     prompt="🔑 Inferex Password",
     hide_input=True,
     confirmation_prompt=False,
@@ -83,11 +85,12 @@ def init(project_path: str, project_name: Optional[str], _: Optional[str]):
 @disable_user_prompts
 def cli_login(username: Optional[str], password: Optional[str], _: Optional[str]):
     """\b
-    🔑  Fetch API key via username & password authentication.
-        \b
-        Username and password can be read from environment variables or set in an .inferex file:
-            INFEREX_USERNAME=myuser
-            INFEREX_PASSWORD=mypassword
+    🔑  Log in to Inferex CLI
+
+    \b
+    Username and password may be set through environment variables or an .inferex file:
+        INFEREX_USERNAME=myuser
+        INFEREX_PASSWORD=mypassword
 
     \f
     Args:
@@ -111,70 +114,76 @@ def cli_login(username: Optional[str], password: Optional[str], _: Optional[str]
 
 
 @cli.command("deploy")
-@click.option("--force",
-    is_flag=True,
-    default=False,
-    help="Uses a random SHA as the deployment ID to bypass duplicate constraints."
-)
+
 @click.option(
     "--token",
     default=None,
     help="Pass in a JWT token instead of reading from local cache."
 )
 @click.option(
-    "--stream",
+    "--project",
+    default=None,
+    help="Project name to for the deployment",
+)
+@click.option("--force",
     is_flag=True,
-    default=True,
-    help="Runs deployment in the foreground and streams logs.",
-    show_default=True
+    default=False,
+    help="Use a random SHA to bypass duplicate constraints."
+)
+@click.option(
+    "--detach",
+    is_flag=True,
+    default=False,
+    help="Detached mode: push the deployment and do not stream logs.",
 )
 @click.argument("path", default=".")
-def deploy(force: Optional[bool], token: Optional[str], path: str, stream: Optional[bool]):
+def deploy(
+    token: Optional[str],
+    project: Optional[str],
+    force: Optional[bool],
+    detach: Optional[bool],
+    path: str
+):
     """
-    🚀  Deploy a project.
+    🚀  Deploy a project
 
-        This command will bundle an application in [PATH] and submit it for processing.
-
-        path: Full or relative path to a project folder.
+        PATH: full or relative path of the project directory
 
     \f
     Args:
         force: Uses a random SHA as the deployment ID to bypass duplicate constraints.
         token: Pass a JWT token instead of reading from local cache.
-        stream: Runs deployment in the background
-        path: Full or relative path to a project folder.
+        detach: Deploy without streaming logs.
+        path: Full or relative path to a project directory.
     """
     click.echo("🐳 Preparing project...")
     start_time = time.time()
     try:
-        response_or_stream = deployment.deploy(path, token, force=force, stream=stream)
+        response_or_stream = deployments.deploy(path, token, project_name=project, force=force, stream=not detach)
     except DeployFailureError as exc:
         error(f"Deploy failed: {exc}")
         sys.exit()
-    except RequirementsValidationException as exc:
-        click.echo(f"Dependency issue with project - {exc}")
-        sys.exit()
     except Exception as exc:
         error(str(exc))
         sys.exit()
 
-    deploy_seconds = time.time() - start_time
-    if stream:
-        for log in response_or_stream:
-            click.echo(log)
-    elif response_or_stream.ok:
+    if detach and response_or_stream.ok:
+        deploy_seconds = time.time() - start_time
         response_ms = str(response_or_stream.elapsed.microseconds / 1000).split(".")[0]
         click.echo(
             f"☁️  The project has been deployed for processing: {response_ms} ms\n"
             "It may take some time before pipelines are reachable."
         )
-        success(f"Pipeline deployed: ({deploy_seconds:.1f} s).")
-    else:
+        click.echo(f"Pipeline deployed: ({deploy_seconds:.1f} s).")
+    elif detach and not response_or_stream.ok:
         error(
             f"""Something went wrong with the deploy.
                 Status code: {response_or_stream.status_code}
                 Message: {response_or_stream.json()}"""
         )
+    else:
+        for log in response_or_stream:
+            click.echo(log)
 
 
 @cli.command("logs")
@@ -185,26 +194,26 @@ def deploy(force: Optional[bool], token: Optional[str], path: str, stream: Optio
 )
 @click.option("--earliest", default=None, help=TIME_HELP_TEXT)
 @click.option("--latest", default=None)
-@click.argument("deployment_git_sha")
-def logs(
+@click.argument("deployment_sha")
+def logs_get(
     limit: Optional[int],
     earliest: Optional[str],
     latest: Optional[str],
-    deployment_git_sha: str,
+    deployment_sha: str,
 ):
     """
-    📃  Get logs from Inferex deployments.
+    📃  Get logs of an Inferex deployment
 
     \f
     Args:
         limit (int): The number of lines to return.
         earliest: How far back to look in time.
         latest: No more recent than this point in time.
-        git_sha: Git sha of a deployment.
+        deployment_sha: deployment_sha of a deployment.
     """
     # request params
     params = {
-            "git_sha": deployment_git_sha,
+            "git_sha": deployment_sha,
             "limit": limit,
             "start": None,
             "end": None,
@@ -233,22 +242,17 @@ def logs(
         dt = dt - delta  # pylint: disable=C0103
         params[key] = dt.isoformat()
 
-    response = log.get(**params)
-    if "error" in response.json():
-        error(
-            f"""Something went wrong with the request.
-                Status code: {response.status_code}
-                Message: {response.json()}"""
-        )
-        sys.exit()
-
-    response_data = fetch_and_handle_response(log.get, "logs", **params)
+    response_data = fetch_and_handle_response(
+        func=logs.get,
+        path="logs",
+        **params
+    )
     display_logs(response_data)
 
 
-@cli.command("reset")
-def reset():
-    """ ❌  Removes the config.json file created at login. """
+@cli.command("logout")
+def logout():
+    """ ❌  Log out from Inferex CLI """
     deleted_file_path = settings.delete_config()
     if deleted_file_path == 1:
         error("config.json not found. Please make sure you've run 'inferex login` first.")
@@ -257,11 +261,13 @@ def reset():
 
 
 # Add subcommands to the "cli" group.
-cli.add_command(project_commands)
-cli.add_command(projects)
-cli.add_command(deployment_commands)
-cli.add_command(deployments)
-cli.add_command(pipelines)
+
+cli.add_command(project_commands, command_group="Resource", priority=1)
+cli.add_command(projects_list)
+cli.add_command(deployment_commands, command_group="Resource", priority=2)
+cli.add_command(deployments_list)
+cli.add_command(pipeline_commands, command_group="Resource", priority=3)
+cli.add_command(pipelines_list)
 
 
 if __name__ == "__main__":
